package sun.java2d;

import java.awt.Rectangle;
import java.awt.image.Raster;
import java.awt.GraphicsConfiguration;
import java.awt.image.ColorModel;
import sun.java2d.loops.SurfaceType;
import sun.java2d.pipe.NullPipe;

public class NullSurfaceData extends SurfaceData
{
    public static final SurfaceData theInstance;
    private static final NullPipe nullpipe;
    
    private NullSurfaceData() {
        super(StateTrackable.State.IMMUTABLE, SurfaceType.Any, ColorModel.getRGBdefault());
    }
    
    @Override
    public void invalidate() {
    }
    
    @Override
    public SurfaceData getReplacement() {
        return this;
    }
    
    @Override
    public void validatePipe(SunGraphics2D sunGraphics2D) {
        sunGraphics2D.drawpipe = NullSurfaceData.nullpipe;
        sunGraphics2D.fillpipe = NullSurfaceData.nullpipe;
        sunGraphics2D.shapepipe = NullSurfaceData.nullpipe;
        sunGraphics2D.textpipe = NullSurfaceData.nullpipe;
        sunGraphics2D.imagepipe = NullSurfaceData.nullpipe;
    }
    
    @Override
    public GraphicsConfiguration getDeviceConfiguration() {
        return null;
    }
    
    @Override
    public Raster getRaster(int n, int n2, int n3, int n4) {
        throw new InvalidPipeException("should be NOP");
    }
    
    @Override
    public boolean useTightBBoxes() {
        return false;
    }
    
    @Override
    public int pixelFor(int n) {
        return n;
    }
    
    @Override
    public int rgbFor(int n) {
        return n;
    }
    
    @Override
    public Rectangle getBounds() {
        return new Rectangle();
    }
    
    @Override
    protected void checkCustomComposite() {
    }
    
    @Override
    public boolean copyArea(SunGraphics2D sunGraphics2D, int n, int n2, int n3, int n4, int n5, int n6) {
        return true;
    }
    
    @Override
    public Object getDestination() {
        return null;
    }
    
    static {
        theInstance = new NullSurfaceData();
        nullpipe = new NullPipe();
    }
}
